You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@santuario.apache.org by mu...@apache.org on 2008/02/07 20:30:00 UTC

svn commit: r619586 - /xml/security/trunk/src/org/apache/xml/security/utils/ElementProxy.java

Author: mullan
Date: Thu Feb  7 11:29:48 2008
New Revision: 619586

URL: http://svn.apache.org/viewvc?rev=619586&view=rev
Log:
Fixed bug 44205: XMLX509Certificate.getX509Certificate() results in certificate parsing error

Modified:
    xml/security/trunk/src/org/apache/xml/security/utils/ElementProxy.java

Modified: xml/security/trunk/src/org/apache/xml/security/utils/ElementProxy.java
URL: http://svn.apache.org/viewvc/xml/security/trunk/src/org/apache/xml/security/utils/ElementProxy.java?rev=619586&r1=619585&r2=619586&view=diff
==============================================================================
--- xml/security/trunk/src/org/apache/xml/security/utils/ElementProxy.java (original)
+++ xml/security/trunk/src/org/apache/xml/security/utils/ElementProxy.java Thu Feb  7 11:29:48 2008
@@ -400,27 +400,23 @@
    /**
     * Method getBytesFromTextChild
     *
     * @return The base64 bytes from the first text child of this element
     * @throws XMLSecurityException
     */
    public byte[] getBytesFromTextChild() throws XMLSecurityException {
-      
-         Text t = (Text)this._constructionElement.getFirstChild();
-                                                   
-
-         return Base64.decode(t.getData());
+      return Base64.decode
+         (XMLUtils.getFullTextChildrenFromElement(this._constructionElement));
    }
 
    /**
     * Method getTextFromTextChild
     *
-    * @return the Text obtained concatening all the the text nodes of this element
+    * @return the Text obtained by concatenating all the text nodes of this 
+    *    element
     */
    public String getTextFromTextChild() {
       return XMLUtils.getFullTextChildrenFromElement(this._constructionElement);
    }
-
-  
 
    /**
     * Method length
@@ -400,27 +400,23 @@
     * Method getBytesFromTextChild
     *
-    * @return The base64 bytes from the first text child of this element
+    * @return The base64 bytes from the text children of this element
     * @throws XMLSecurityException
     */